@@ -20,12 +20,15 @@ class ExecuteConfigNode:
     FILE = "file"
     WITH = "with"
     RESULT = "result"
+    LOCAL = "_execution_results"
 
 
 class AssertConfigNode:
     """represent asserts config section"""
 
     ROOT = "asserts"
+    LOCAL = "_assertion_results"
+
     TYPE = "type"
     ACTUAL = "actual"
     ACTUAL_ORIG = "actual_original"
