@@ -19,28 +19,24 @@ class StringLexicalAnalyzer:
         if len(replace_with) == 0:
             return container
 
-        line_split = re.split(
-            r"({\s*\$[a-zA-Z0-9_.]+\s*})|(\s*\$[a-zA-Z0-9_.]+)", container
-        )
+        line_split = re.split(r"({\$[a-zA-Z0-9_.]+})", container)
+
+        if len(line_split) == 1 and container in line_split:
+            return container
+
         line_strip = [
             "".join(item.split() if "$" in item else item)
             for item in line_split
             if item
         ]
 
-        if len(line_strip) == 1:
-            item = line_strip.pop()
-            if "$" not in item:
-                return container
-
-            t_item = item.strip("{}").lstrip("$")
-            value = data_get(replace_with, t_item)
-            return value if value else "{ $" + t_item + " }"
-
         for i, item in enumerate(line_strip):
-            item = item.strip("{}")
-            if item.startswith("$"):
-                value = data_get(replace_with, item.lstrip("$"), None)
-                line_strip[i] = str(value) if value else "{" + item + "}"
+            if "$" in item:
+                value = data_get(replace_with, item.strip("{$}"), None)
+                line_strip[i] = value or item
 
-        return "".join(line_strip)
+        return (
+            "".join([str(li) for li in line_strip])
+            if len(line_strip) > 1
+            else line_strip.pop()
+        )
